<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>RETAS レベル形式</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>非圧縮AVIビデオに制限はありません</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>ビデオ幅は %1 の倍数でなければなりません</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>ビデオの長さは %1 の倍数でなければなりません</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>このコーデックに制限はありません</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>ピクセルサイズの制限:</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>コーデックの呼び出しができません。
このコーデックは正常に動作しない恐れがあります。</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation></translation>
    </message>
    <message>
        <source>%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>%2 に %1 引数を予想していましたが、%3 が入力されました</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 は有効な色ではありません（有効な色名は&apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos; 等です）</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>ベクター化に失敗しました</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>引数はファイルパスではありません : %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>不正な引数（%1）: 画像を指定する必要があります</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>引数 &apos;%1&apos; は フレームインデックスではありません</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>1番目の引数はシーンである必要があります : %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>空のシーンはレンダリングできません</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>新規カメラ  %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>新規タップ  %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>アクティブカメラの変更  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>スプラインの削除  %1</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>新規モーションパス  %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>モーションパスをリンク  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>オブジェクトを削除  %1</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>列の削除</translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>現在のパレット内に読み込み  &gt; %1</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>現在のパレットで置き換え &gt; %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>スタジオパレットを削除  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>スタジオパレットを作成  : %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>スタジオパレットフォルダの削除  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>スタジオパレットフォルダの作成  : %1</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>スタジオパレットフォルダの移動  : %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>スタイルの並べ替え : パレット %1</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>スタイル#%1 を作成 : パレット %2</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation>スタイルを追加 : パレット %1</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>ページ %1 の追加 : パレット %2</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>ページ %1 の削除 : パレット %2</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>カラーモデル %1 を読み込み : パレット %2</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>ページを移動</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>ページのリネーム  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>スタイル#%1 のリネーム : パレット %2  : %3 &gt; %4</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>エフェクトを追加  : </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>エフェクトを挿入  : </translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>リンクされたエフェクトを作成  : %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>エフェクトを置き換え  : </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>エフェクトのリンクを解除  : %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>マクロエフェクトの作成  : %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>マクロエフェクトを展開  : %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>出力ノードを作成</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>タイムシートノードに接続  : </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>タイムシートノードから接続を解除 : </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>リンクを削除</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>エフェクトノードを削除 : %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>エフェクトを貼り付け : </translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>エフェクトの接続を解除</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>エフェクトを接続 : %1 - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>エフェクトをリネーム : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>エフェクトをグループ化</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>エフェクトのグループを解除</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>グループをリネーム  : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>キーフレームを設定</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>キーフレームを削除</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>サイクル</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>現在の画像上で、自動センタリングが失敗しました。</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>移動</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>回転角を変更</translation>
    </message>
    <message>
        <source>Move X</source>
        <translation>左右に移動</translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation>上下に移動</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>奥行き方向に移動</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>重ね順を変更</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>横方向の倍率を変更</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>縦方向の倍率を変更</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>倍率を変更</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>パス上の位置を変更</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation>横方向のシアーを変更</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation>縦方向のシアーを変更</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  フレーム : %3</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>キーフレームを設定   %1  フレーム %2</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>キーフレームを消去   %1  フレーム %2</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation>センター位置を移動   %1  フレーム %2</translation>
    </message>
    <message>
        <source>color model</source>
        <translation>カラーモデル</translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>パレット%2のスタイル#%1のサンプル位置を設定： （%3,%4）</translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>パレット%1&#x3000;サンプル位置を用いて色を更新</translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation>保存できません ：</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>赤</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>緑</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>青</translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation>暗い黄色</translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation>暗いシアン</translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation>暗いマゼンタ</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>明るさ</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>コントラスト</translation>
    </message>
    <message>
        <source>HRange</source>
        <translation>色相の範囲</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>線の太さ</translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation>色のしきい値</translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation>明るさのしきい値</translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>含め塗りの切り替え : パレット %1  スタイル#%2</translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation>パレットのリネーム操作を元に戻せません</translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation>パレットの移動操作を元に戻せません</translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation>パレットのリネーム操作をやり直せません</translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation>パレットの移動操作をやり直せません</translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>スタジオパレットをリネーム : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation>タイムシート</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>タイムライン</translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation>以下の素材の保存に失敗しました：
</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>パレットの保存に失敗しました。</translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation>さらに %1 個のファイル。</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>オレンジ</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation>黄緑</translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation>水色</translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation>暗い青</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>紫</translation>
    </message>
    <message>
        <source>Pink</source>
        <translation>ピンク</translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation>暗いピンク</translation>
    </message>
    <message>
        <source>White</source>
        <translation>白</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>レベル%1をベクター化できません</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>フレームのないレベルはベクター化できません</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>画像 %1 をベクター化できません</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>不正な引数 (%1): 画像またはレベルを指定する必要があります</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>絶対パス %1 を連結することができません</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 はディレクトリではありません</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>ディレクトリ %1 を読み取ることができません</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>ファイル %1 は存在しません</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>%1 の最初のフレームを読み込みました</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>画像の読み取り中に想定外のエラーが発生しました</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>認識できないファイル形式 :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>画像 %1 をこのファイル形式で保存できません : %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>画像の書き込み中に想定外のエラーが発生しました</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>不正な引数 (%1): ラスターまたはToonzラスターを指定する必要があります</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>イメージビルダー(%1 画像)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>不正な引数 (%1): 幾何変換を指定する必要があります</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 フレーム</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>不正な引数 (%1): ファイルパスまたは文字列を指定する必要があります</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>レベル読み込みの例外 (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>ファイル %1 は存在しません</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>ファイル %1 はサポートされていません</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 読み取り中の例外</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>空のレベルを保存できません</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>認識できないファイル形式 :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>レベル %1 をこのファイル形式で保存できません : %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 書き込み中の例外</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>フレームインデックス (%1) は数字でなくてはなりません</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>フレームインデックス (%1)は範囲外です (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>2番目の引数 (%1) が画像ではありません</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>画像 %1 をレベルに挿入できません</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>画像 %1 をレベル %2 に挿入できません</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>レベル%1をベクター化できません</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>フレームのないレベルはベクター化できません</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>画像 %1 をベクター化できません</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>不正な引数 (%1): 画像またはレベルを指定する必要があります</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>無効な色 : </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>ベクター画像ではありません: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>ベクターレベルではありません: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>引数はベクターレベルまたは画像である必要があります : </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>%1 にはパレットがありません</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>ファイル %1 は存在しません</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>%1 読み取り中の例外</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>%1 書き込み中の例外</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>不正なレベルタイプ (%1): ベクター、ラスターまたはToonzラスターである必要があります</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>レベルを追加できません: レベル名(%1)は既に使用されています</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>この形式のファイルをレベルとして読み込むことはできません : %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>レベル %1 を読み込めませんでした</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>レベルはシーンに含まれていません : %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1 : レベルインスタンスまたはレベルではありません</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>レベル &apos;%1&apos; はシーンに含まれていません</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>レベル%1を変換できません</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>フレームのないレベルは変換できません</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>画像%1を変換できません</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>不正な引数 (%1): レベルまたはラスター画像を指定する必要があります</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>単位行列</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>移動(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>回転(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>拡大縮小(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>拡大縮小(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>幾何変換(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
